import { FastifyInstance } from 'fastify';
import { SummaryController, SummaryControllerImpl } from './modules/summary';
import { TranscriptController, TranscriptControllerImpl } from './modules/transcript/TranscriptController';

export const addHealthRoutes = (server: FastifyInstance) => {
  server
    .route({
      method: 'GET',
      url: '/api/health/live',
      handler: async (_, reply) => {
        reply.send({ status: 'ok' });
      },
    })
    .route({
      method: 'GET',
      url: '/api/health/ready',
      handler: async (_, reply) => {
        reply.send({ status: 'ok' });
      },
    });
};

export const addSummaryRoutes = (server: FastifyInstance) => {
  const summaryController: SummaryController = new SummaryControllerImpl();
  server
    .route({
      method: 'POST',
      url: '/api/summarize',
      handler: summaryController.summarizeVideoTranscript,
    });
};

export const addTranscriptRoutes = (server: FastifyInstance) => {
  const transcriptController: TranscriptController = new TranscriptControllerImpl();
  server
    .route({
      method: 'GET',
      url: '/api/transcripts/get/:videoType/:videoId',
      handler: transcriptController.getVideoTranscript,
    })
    .route({
      method: 'POST',
      url: '/api/transcripts/normalize',
      handler: transcriptController.normalizeVideoTranscriptText,
    });
};
